@@ -4,13 +4,13 @@
 #' Probable here implies more probable than in a corpus overall.
 #' @param docnames A character vector of rownames of dtm for set of documents
 #' @param dtm A document term matrix of class \code{matrix} or \code{dgCMatrix}.
-#' @param p.terms If not NULL (the default), a numeric vector representing the 
+#' @param p_terms If not NULL (the default), a numeric vector representing the 
 #' probabiliy of each term in the corpus whose names correspond to colnames(dtm). 
 #' @return
-#' Returns a numeric vector of the format p.terms. The entries of the vectors 
+#' Returns a numeric vector of the format p_terms. The entries of the vectors 
 #' correspond to the difference in the probability of drawing a term from the 
 #' set of documents given by docnames and the probability of drawing that term 
-#' from the corpus overall (p.terms).
+#' from the corpus overall (p_terms).
 #' 
 #' @export
 #' @examples
@@ -23,27 +23,27 @@
 #' 
 #' term_probs <- Matrix::colSums(nih_sample_dtm) / sum(Matrix::colSums(nih_sample_dtm))
 #' 
-#' GetProbableTerms(docnames = mydocs, dtm = nih_sample_dtm, p.terms = term_probs)
+#' GetProbableTerms(docnames = mydocs, dtm = nih_sample_dtm, p_terms = term_probs)
 #' 
-GetProbableTerms <- function(docnames, dtm, p.terms=NULL){
+GetProbableTerms <- function(docnames, dtm, p_terms=NULL){
     
     
-    # if p.terms is NULL, then create p.terms
-    if( is.null(p.terms) ){
-        p.terms <- Matrix::colSums(dtm) / sum(Matrix::colSums(dtm))
+    # if p_terms is NULL, then create p_terms
+    if( is.null(p_terms) ){
+        p_terms <- Matrix::colSums(dtm) / sum(Matrix::colSums(dtm))
     }
     
     # get probability of terms given docnames
     if( length(docnames) == 1 ){ 
-        p.terms.given.docs <- dtm[ docnames , ] 
+        p_terms.given.docs <- dtm[ docnames , ] 
     }else{
-        p.terms.given.docs <- Matrix::colSums(dtm[ docnames , ])
+        p_terms.given.docs <- Matrix::colSums(dtm[ docnames , ])
     }
     
-    p.terms.given.docs <- p.terms.given.docs/sum(p.terms.given.docs)
+    p_terms.given.docs <- p_terms.given.docs/sum(p_terms.given.docs)
     
     # get our result, the difference
-    result <- p.terms.given.docs - p.terms
+    result <- p_terms.given.docs - p_terms
     
     names(result) <- colnames(dtm)
     
